==> haskell-th-extras-0.0.0.4-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-extras
version:              0.0.0.4
visibility:           public
id:                   th-extras-0.0.0.4-LBLKZ0jQ9aoDf3T1mSOBNw
key:                  th-extras-0.0.0.4-LBLKZ0jQ9aoDf3T1mSOBNw
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/mokus0/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  d2bc73e2222c315ca1cc60f5fca1579c
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-8.10.3/site-local/th-extras-0.0.0.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/th-extras-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/th-extras-0.0.0.4
hs-libraries:         HSth-extras-0.0.0.4-LBLKZ0jQ9aoDf3T1mSOBNw
depends:
    base-4.14.1.0 syb-0.7.2.1-IMisWBQ73CcBLtEce0DtDe
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-extras-0.0.0.4-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-extras
version:              0.0.0.4
visibility:           public
id:                   th-extras-0.0.0.4-351R1HXmqMmJXrvzf2Gmz2
key:                  th-extras-0.0.0.4-351R1HXmqMmJXrvzf2Gmz2
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/mokus0/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  cba5b6336201ce818ce501a9fffa2c63
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-8.10.3/site-local/th-extras-0.0.0.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/th-extras-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/th-extras-0.0.0.4
hs-libraries:         HSth-extras-0.0.0.4-351R1HXmqMmJXrvzf2Gmz2
depends:
    base-4.14.1.0 syb-0.7.2.1-7YteKEvijmt5wSroPLHLQq
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
